@@ -5,7 +5,7 @@
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 ;; Maintainer: Eric Abrahamsen <eric@ericabrahamsen.net>
 ;; Package-Type: multi
-;; Version: 0.3.0
+;; Version: 0.4.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -139,7 +139,7 @@ Gnus settings pre-loaded.  Any of the normal Gnus entry points
 will start a mock Gnus session."
   (interactive)
   (let ((mock-tmp-dir (make-temp-file "emacs-gnus-mock-" t)))
-    (condition-case nil
+    (condition-case-unless-debug err
 	(let ((init-file (expand-file-name "init.el" mock-tmp-dir)))
 	  (with-temp-buffer
 	    (let ((standard-output (current-buffer))
@@ -255,13 +255,20 @@ will start a mock Gnus session."
 						      %Seen %Draft %*))))))
 	       (current-buffer)))
 	    (basic-save-buffer))
-	  (make-process :name "gnus-mock" :buffer nil
-			:command (list gnus-mock-emacs-program
-				       "-Q" "--load" init-file)
-			:stderr "*gnus mock errors*"))
+	  (let ((default-directory
+		  (expand-file-name
+		   "lisp/gnus"
+		   (file-name-as-directory
+		    (expand-file-name "../.."
+				      gnus-mock-emacs-program)))))
+	    (make-process :name "gnus-mock" :buffer nil
+			  :command (list gnus-mock-emacs-program
+					 "-Q" "--load" init-file)
+			  :stderr "*gnus mock errors*")))
       (error (when (and gnus-mock-cleanup-p
 			(file-exists-p mock-tmp-dir))
-	       (delete-directory mock-tmp-dir t))))))
+	       (delete-directory mock-tmp-dir t))
+	     (signal (car err) (cdr err))))))
 
 (provide 'gnus-mock)
 ;;; gnus-mock.el ends here
